==> openshift-model-operator-5.7.3-sources.jar: io/fabric8/openshift/api/model/operator/v1/IngressControllerHTTPUniqueIdHeaderPolicyBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class IngressControllerHTTPUniqueIdHeaderPolicyBuilder extends io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPUniqueIdHeaderPolicyFluentImpl<io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPUniqueIdHeaderPolicyBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPUniqueIdHeaderPolicy,io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPUniqueIdHeaderPolicyBuilder>{
  public IngressControllerHTTPUniqueIdHeaderPolicyBuilder() {
    this(false);
  }
  public IngressControllerHTTPUniqueIdHeaderPolicyBuilder(java.lang.Boolean validationEnabled) {
    this(new IngressControllerHTTPUniqueIdHeaderPolicy(), validationEnabled);
  }
  public IngressControllerHTTPUniqueIdHeaderPolicyBuilder(io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPUniqueIdHeaderPolicyFluent<?> fluent) {
    this(fluent, false);
  }
  public IngressControllerHTTPUniqueIdHeaderPolicyBuilder(io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPUniqueIdHeaderPolicyFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new IngressControllerHTTPUniqueIdHeaderPolicy(), validationEnabled);
  }
  public IngressControllerHTTPUniqueIdHeaderPolicyBuilder(io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPUniqueIdHeaderPolicyFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPUniqueIdHeaderPolicy instance) {
    this(fluent, instance, false);
  }
  public IngressControllerHTTPUniqueIdHeaderPolicyBuilder(io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPUniqueIdHeaderPolicyFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPUniqueIdHeaderPolicy instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withFormat(instance.getFormat()); 
    fluent.withName(instance.getName()); 
    this.validationEnabled = validationEnabled; 
  }
  public IngressControllerHTTPUniqueIdHeaderPolicyBuilder(io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPUniqueIdHeaderPolicy instance) {
    this(instance,false);
  }
  public IngressControllerHTTPUniqueIdHeaderPolicyBuilder(io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPUniqueIdHeaderPolicy instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withFormat(instance.getFormat()); 
    this.withName(instance.getName()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPUniqueIdHeaderPolicyFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPUniqueIdHeaderPolicy build() {
    IngressControllerHTTPUniqueIdHeaderPolicy buildable = new IngressControllerHTTPUniqueIdHeaderPolicy(fluent.getFormat(),fluent.getName());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    IngressControllerHTTPUniqueIdHeaderPolicyBuilder that = (IngressControllerHTTPUniqueIdHeaderPolicyBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-operator-5.11.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/IngressControllerHTTPUniqueIdHeaderPolicyBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class IngressControllerHTTPUniqueIdHeaderPolicyBuilder extends io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPUniqueIdHeaderPolicyFluentImpl<io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPUniqueIdHeaderPolicyBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPUniqueIdHeaderPolicy,io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPUniqueIdHeaderPolicyBuilder>{
  public IngressControllerHTTPUniqueIdHeaderPolicyBuilder() {
    this(false);
  }
  public IngressControllerHTTPUniqueIdHeaderPolicyBuilder(java.lang.Boolean validationEnabled) {
    this(new IngressControllerHTTPUniqueIdHeaderPolicy(), validationEnabled);
  }
  public IngressControllerHTTPUniqueIdHeaderPolicyBuilder(io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPUniqueIdHeaderPolicyFluent<?> fluent) {
    this(fluent, false);
  }
  public IngressControllerHTTPUniqueIdHeaderPolicyBuilder(io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPUniqueIdHeaderPolicyFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new IngressControllerHTTPUniqueIdHeaderPolicy(), validationEnabled);
  }
  public IngressControllerHTTPUniqueIdHeaderPolicyBuilder(io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPUniqueIdHeaderPolicyFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPUniqueIdHeaderPolicy instance) {
    this(fluent, instance, false);
  }
  public IngressControllerHTTPUniqueIdHeaderPolicyBuilder(io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPUniqueIdHeaderPolicyFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPUniqueIdHeaderPolicy instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withFormat(instance.getFormat()); 
    fluent.withName(instance.getName()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public IngressControllerHTTPUniqueIdHeaderPolicyBuilder(io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPUniqueIdHeaderPolicy instance) {
    this(instance,false);
  }
  public IngressControllerHTTPUniqueIdHeaderPolicyBuilder(io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPUniqueIdHeaderPolicy instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withFormat(instance.getFormat()); 
    this.withName(instance.getName()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPUniqueIdHeaderPolicyFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPUniqueIdHeaderPolicy build() {
    IngressControllerHTTPUniqueIdHeaderPolicy buildable = new IngressControllerHTTPUniqueIdHeaderPolicy(fluent.getFormat(),fluent.getName());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    IngressControllerHTTPUniqueIdHeaderPolicyBuilder that = (IngressControllerHTTPUniqueIdHeaderPolicyBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
